mailr7039 - /1.3/specific_fns/model_free/main.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by sebastien . morin . 1 on July 30, 2008 - 21:26:
Author: semor
Date: Wed Jul 30 21:26:04 2008
New Revision: 7039

URL: http://svn.gna.org/viewcvs/relax?rev=7039&view=rev
Log:
Conversion of a run argument to pipe, etc.


Modified:
    1.3/specific_fns/model_free/main.py

Modified: 1.3/specific_fns/model_free/main.py
URL: 
http://svn.gna.org/viewcvs/relax/1.3/specific_fns/model_free/main.py?rev=7039&r1=7038&r2=7039&view=diff
==============================================================================
--- 1.3/specific_fns/model_free/main.py (original)
+++ 1.3/specific_fns/model_free/main.py Wed Jul 30 21:26:04 2008
@@ -845,10 +845,10 @@
         if not ds.current_pipe:
             raise RelaxNoPipeError
 
-        # Test if the run type is set to 'mf'.
-        function_type = ds.run_types[ds.run_names.index(self.run)]
+        # Test if the pipe type is set to 'mf'.
+        function_type = ds[ds.current_pipe].pipe_type
         if function_type != 'mf':
-            raise RelaxFuncSetupError, 
self.relax.specific_setup.get_string(function_type)
+            raise RelaxFuncSetupError, 
specific_fns.setup.get_string(function_type)
 
         # Test if the sequence data is loaded.
         if not exists_mol_res_spin_data():




Related Messages


Powered by MHonArc, Updated Wed Jul 30 23:00:32 2008